@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2017 Gehirn Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,38 +12,37 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .jwa import std_hash_by_alg
+from .jwa import (
+    AbstractSigningAlgorithm,
+    std_hash_by_alg,
+    supported_signing_algorithms,
+)
 from .jwk import (
     AbstractJWKBase,
-    jwk_from_dict,
     jwk_from_bytes,
-    jwk_from_pem,
     jwk_from_der,
+    jwk_from_dict,
+    jwk_from_pem,
     supported_key_types,
 )
 from .jwkset import JWKSet
-from .jwa import (
-    AbstractSigningAlgorithm,
-    supported_signing_algorithms,
-)
 from .jwt import JWT
 
-
 __all__ = [
     # .jwa
-    'std_hash_by_alg',
+    "std_hash_by_alg",
     # .jwk
-    'AbstractJWKBase',
-    'jwk_from_bytes',
-    'jwk_from_dict',
-    'jwk_from_pem',
-    'jwk_from_der',
-    'supported_key_types',
+    "AbstractJWKBase",
+    "jwk_from_bytes",
+    "jwk_from_dict",
+    "jwk_from_pem",
+    "jwk_from_der",
+    "supported_key_types",
     # .jwkset
-    'JWKSet',
+    "JWKSet",
     # .jws
-    'AbstractSigningAlgorithm',
-    'supported_signing_algorithms',
+    "AbstractSigningAlgorithm",
+    "supported_signing_algorithms",
     # .jwt
-    'JWT',
+    "JWT",
 ]
